@@ -20,24 +20,28 @@ import abc
 from itertools import count
 from typing import Mapping, Optional, Union
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
+
 import numpy as np
 
-from pydrobert.speech import AliasedFactory
+from pydrobert.speech.alias import AliasedFactory, alias_factory_subclass_from_arg
 from pydrobert.speech import config
 from pydrobert.speech.filters import GammaWindow
 from pydrobert.speech.filters import HannWindow
 from pydrobert.speech.filters import LinearFilterBank
 from pydrobert.speech.filters import WindowFunction
-from pydrobert.speech.util import alias_factory_subclass_from_arg
 
 __all__ = [
+    "frame_by_frame_calculation",
     "FrameComputer",
     "LinearFilterBankFrameComputer",
-    "ShortTimeFourierTransformFrameComputer",
-    "STFTFrameComputer",
     "ShortIntegrationFrameComputer",
+    "ShortTimeFourierTransformFrameComputer",
     "SIFrameComputer",
-    "frame_by_frame_calculation",
+    "STFTFrameComputer",
 ]
 
 
@@ -65,71 +69,57 @@ class FrameComputer(AliasedFactory):
     The k-th frame can be roughly localized to the signal offset to about ``signal[k *
     computer.frame_shift]``. The signal's exact region of influence is dictated by the
     `frame_style` property.
-
-    Attributes
-    ----------
-    frame_style : {'causal', 'centered'}
-    sampling_rate : float
-    frame_length : int
-    frame_length_ms : float
-    frame_shift : int
-    frame_shift_ms : float
-    num_coeffs : int
-    started : bool
     """
 
     @abc.abstractproperty
-    def frame_style(self) -> str:
-        """Dictates how the signal is split into frames
+    def frame_style(self) -> Literal["causal", "centered"]:
+        """str : Dictates how the signal is split into frames
 
-        If ``'causal'``, the k-th frame is computed over the indices ``signal[k
-        * frame_shift:k * frame_shift + frame_length]`` (at most). If
-        ``'centered'``, the k-th frame is computed over the indices ``signal[k
-        * frame_shift - (frame_length + 1) // 2 + 1:k * frame_shift +
-        frame_length // 2 + 1]``. Any range beyond the bounds of the signal is
-        generated in an implementation-specific way.
+        If :obj:`'causal'`, the k-th frame is computed over the indices ``signal[k *
+        frame_shift:k * frame_shift + frame_length]`` (at most). If :obj:`'centered'`,
+        the k-th frame is computed over the indices ``signal[k * frame_shift -
+        (frame_length + 1) // 2 + 1:k * frame_shift + frame_length // 2 + 1]``. Any
+        range beyond the bounds of the signal is generated in an implementation-specific
+        way.
         """
         pass
 
     @abc.abstractproperty
     def sampling_rate(self) -> float:
-        """Number of samples in a second of a target recording"""
+        """float : Number of samples in a second of a target recording"""
         pass
 
     @abc.abstractproperty
     def frame_length(self) -> int:
-        """Number of samples which dictate a feature vector
-
-        .. warning:: Can be different from `get_next_segment_length`
-        """
+        """int : Number of samples which dictate a feature vector"""
         pass
 
     @property
     def frame_length_ms(self) -> float:
-        """Number of milliseconds of audio which dictate a feature vector"""
+        """float : Number of milliseconds of audio which dictate a feature vector"""
         return self.frame_length * 1000 / self.sampling_rate
 
     @abc.abstractproperty
     def frame_shift(self) -> int:
-        """Number of samples absorbed between successive frame computations"""
+        """int : Number of samples absorbed between successive frame computations"""
         pass
 
     @property
     def frame_shift_ms(self) -> float:
-        """Number of milliseconds between succecssive frame computations"""
+        """float : Number of milliseconds between succecssive frame computations"""
         return self.frame_shift * 1000 / self.sampling_rate
 
     @abc.abstractproperty
     def num_coeffs(self) -> int:
-        """Number of coefficients returned per frame"""
+        """int : Number of coefficients returned per frame"""
         pass
 
     @abc.abstractproperty
     def started(self) -> bool:
-        """Whether computations for a signal have started
+        """bool : Whether computations for a signal have started
 
-        Becomes :obj:`True` after the first call to ``compute_chunk()``. Becomes
-        ``False`` after call to ``finalize()``
+        Becomes :obj:`True` after the first call to :func:`compute_chunk`. Becomes
+        :obj:`False` after call to :func:`finalize`
         """
         pass
 
@@ -139,17 +129,16 @@ class FrameComputer(AliasedFactory):
 
         Parameters
         ----------
-        chunk : array-like
-            A 1D float array of the signal. Should be contiguous and
-            non-overlapping with any previously processed segments in
-            the audio stream
+        chunk
+            A 1D float array of the signal. Should be contiguous and non-overlapping
+            with any previously processed segments in the audio stream
 
         Returns
         -------
-        array-like
-            A 2D float array of shape ``(num_frames, num_coeffs)``.
-            ``num_frames`` is nonnegative (possibly 0). Contains some
-            number of feature vectors, ordered in time over axis 0.
+        chunk : np.ndarray
+            A 2D float array of shape ``(num_frames, num_coeffs)``. ``num_frames`` is
+            nonnegative (possibly 0). Contains some number of feature vectors, ordered
+            in time over axis 0.
         """
         pass
 
@@ -159,9 +148,9 @@ class FrameComputer(AliasedFactory):
 
         Returns
         -------
-        array-like
-            A 2D float array of shape ``(num_frames, num_coeffs)``.
-            ``num_frames`` is either 1 or 0.
+        chunk : np.ndarray
+            A 2D float array of shape ``(num_frames, num_coeffs)``. ``num_frames`` is
+            either 1 or 0.
         """
         pass
 
@@ -170,21 +159,21 @@ class FrameComputer(AliasedFactory):
 
         Parameters
         ----------
-        signal : array-like
+        signal
             A 1D float array of the entire signal
 
         Returns
         -------
-        array-like
-            A 2D float array of shape ``(num_frames, num_coeffs)``.
-            ``num_frames`` is nonnegative (possibly 0). Contains some
-            number of feature vectors, ordered in time over axis 0.
+        spec : np.ndarray
+            A 2D float array of shape ``(num_frames, num_coeffs)``. ``num_frames`` is
+            nonnegative (possibly 0). Contains some number of feature vectors, ordered
+            in time over axis 0.
 
         Raises
         ------
         ValueError
-            If already begin computing frames (``started=True``), and
-            `reset` has not been called
+            If already begin computing frames (``started=True``), and :func:`finalize`
+            has not been called
         """
         return frame_by_frame_calculation(self, signal)
 
@@ -199,19 +188,13 @@ class LinearFilterBankFrameComputer(FrameComputer):
 
     Parameters
     ----------
-    bank : pydrobert.speech.filters.LinearFilterBank, dict, or str
-        Each filter in the bank corresponds to a coefficient in a
-        frame vector. Can be a LinearFilterBank or something compatible
-        with `pydrobert.speech.alias_factory_subclass_from_arg`
-    include_energy : bool, optional
-        Whether to include a coefficient based on the energy of the
-        signal within the frame. If :obj:`True`, the energy coefficient
-        will be inserted at index 0.
-
-    Attributes
-    ----------
-    bank : pydrobert.speech.filters.LinearFilterBank
-    includes_energy : bool
+    bank
+        Each filter in the bank corresponds to a coefficient in a frame vector. Can be a
+        :class:`LinearFilterBank` or something compatible with
+        :func:`pydrobert.speech.alias.alias_factory_subclass_from_arg`
+    include_energy
+        Whether to include a coefficient based on the energy of the signal within the
+        frame. If :obj:`True`, the energy coefficient will be inserted at index 0.
     """
 
     def __init__(
@@ -222,12 +205,12 @@ class LinearFilterBankFrameComputer(FrameComputer):
 
     @property
     def bank(self) -> LinearFilterBank:
-        """The LinearFilterBank from which features are derived"""
+        """LinearFilterBank : The LinearFilterBank from which features are derived"""
         return self._bank
 
     @property
     def includes_energy(self) -> bool:
-        """Whether the first coefficient is an energy coefficient"""
+        """bool : Whether the first coefficient is an energy coefficient"""
         return self._include_energy
 
     @property
@@ -268,55 +251,45 @@ class ShortTimeFourierTransformFrameComputer(LinearFilterBankFrameComputer):
 
     Parameters
     ----------
-    bank : LinearFilterBank or dict or str
-    frame_length_ms : float, optional
+    bank
+        Each filter in the bank corresponds to a coefficient in a frame vector. Can be a
+        :class:`LinearFilterBank` or something compatible with
+        :func:`pydrobert.speech.alias.alias_factory_subclass_from_arg`
+    frame_length_ms
         The length of a frame, in milliseconds. Defaults to the length of the largest
         filter in the bank
     frame_shift_ms : float, optional
         The offset between successive frames, in milliseconds
-    frame_style : {'causal', 'centered'}, optional
-        Defaults to ``'centered'`` if ``bank.is_zero_phase``, ``'causal'`` otherwise.
-    include_energy : bool, optional
-    pad_to_nearest_power_of_two : bool, optional
+    frame_style
+        Defaults to :obj:`'centered'` if ``bank.is_zero_phase``, :obj:`'causal'`
+        otherwise.
+    include_energy
+    pad_to_nearest_power_of_two
         Whether the DFT should be a padded to a power of two for computational
         efficiency
-    window_function : pydrobert.speech.filters.WindowFunction, dict, or str
+    window_function
         The window used in step 1. Can be a :class:`WindowFunction` or something
         compatible with :func:`pydrobert.speech.alias_factory_subclass_from_arg`.
         Defaults to :class:`pydrobert.speech.filters.GammaWindow` when `frame_style` is
-        ``'causal'``, otherwise :class:`pydrobert.speech.filters.HannWindow`.
-    use_log : bool, optional
+        :obj:`'causal'`, otherwise :class:`pydrobert.speech.filters.HannWindow`.
+    use_log
         Whether to take the log of the sum from 3b.
-    use_power : bool, optional
+    use_power
         Whether to sum the power spectrum or the magnitude spectrum
-    kaldi_shift : bool, optional
+    kaldi_shift
         If :obj:`True`, the k-th frame will be computed using the signal between
         ``signal[ k - frame_length // 2 + frame_shift // 2:k + (frame_length + 1) // 2
         + frame_shift // 2]``. These are the frame bounds for Kaldi [povey2011]_.
-
-    Attributes
-    ----------
-    bank : pydrobert.speech.filters.LinearFilterBank
-    frame_style : {'causal', 'centered'}
-    sampling_rate : float
-    frame_length : int
-    frame_length_ms : float
-    frame_shift : int
-    frame_shift_ms : float
-    include_energy : bool
-    num_coeffs : int
-    started : bool
-    kaldi_shift : bool
     """
 
-    aliases = {"stft"}
+    aliases = {"stft"}  #:
 
     def __init__(
         self,
         bank: Union[LinearFilterBank, Mapping, str],
         frame_length_ms: Optional[float] = None,
         frame_shift_ms: Optional[float] = 10,
-        frame_style: Optional[str] = None,
+        frame_style: Optional[Literal["causal", "centered"]] = None,
         include_energy: bool = False,
         pad_to_nearest_power_of_two: bool = True,
         window_function: Optional[Union[WindowFunction, Mapping, str]] = None,
@@ -637,69 +610,57 @@ STFTFrameComputer = ShortTimeFourierTransformFrameComputer
 class ShortIntegrationFrameComputer(LinearFilterBankFrameComputer):
     """Compute features by integrating over the filter modulus
 
-    Each filter in the bank is convolved with the signal. A pointwise
-    nonlinearity pushes the frequency band towards zero. Most of the
-    energy of the signal can be captured in a short time integration.
-    Though best suited to processing whole utterances at once, short
-    integration is compatable with the frame analogy if the frame is
-    assumed to be the cone of influence of the maximum-length filter.
+    Each filter in the bank is convolved with the signal. A pointwise nonlinearity
+    pushes the frequency band towards zero. Most of the energy of the signal can be
+    captured in a short time integration. Though best suited to processing whole
+    utterances at once, short integration is compatable with the frame analogy if the
+    frame is assumed to be the cone of influence of the maximum-length filter.
 
-    For computational purposes, each filter's impulse response is
-    clamped to zero outside the support of the largest filter in the
-    bank, making it a finite impulse response filter. This effectively
-    decreases the frequency resolution of the filters which aren't
-    already FIR. For better frequency resolution at the cost of
-    computational time, increase `EFFECTIVE_SUPPORT_THRESHOLD`.
+    For computational purposes, each filter's impulse response is clamped to zero
+    outside the support of the largest filter in the bank, making it a finite impulse
+    response filter. This effectively decreases the frequency resolution of the filters
+    which aren't already FIR. For better frequency resolution at the cost of
+    computational time, increase
+    :obj:`pydrobert.speech.config.EFFECTIVE_SUPPORT_THRESHOLD`.
 
     Parameters
     ----------
-    bank : pydrobert.speech.filters.LinearFilterBank or dict or str
-    frame_shift_ms : float, optional
-        The offset between successive frames, in milliseconds. Also the
-        length of the integration
-    frame_style : {'causal', 'centered'}, optional
-        Defaults to ``'centered'`` if `bank.is_zero_phase`, ``'causal'``
-        otherwise. If ``'centered'`` each filter of the bank is
-        translated so that its support lies in the center of the frame
-    include_energy : bool, optional
-    pad_to_nearest_power_of_two : bool, optional
-        Pad the DFTs used in computation to a power of two for
-        efficient computation
+    bank
+        Each filter in the bank corresponds to a coefficient in a frame vector. Can be a
+        :class:`LinearFilterBank` or something compatible with
+        :func:`pydrobert.speech.alias.alias_factory_subclass_from_arg`
+    frame_shift_ms
+        The offset between successive frames, in milliseconds. Also the length of the
+        integration
+    frame_style
+        Defaults to :obj:`'centered'` if `bank.is_zero_phase`, :obj:`'causal'`
+        otherwise. If :obj:`'centered'` each filter of the bank is translated so that
+        its support lies in the center of the frame
+    include_energy
+    pad_to_nearest_power_of_two
+        Pad the DFTs used in computation to a power of two for efficient computation
     window_function : pydrobert.speech.filters.WindowFunction, dict, or str
         The window used to weigh integration. Can be a :class:`WindowFunction` or
         something compatible with
         :func:`pydrobert.speech.alias_factory_subclass_from_arg`. Defaults to
         :class:`pydrobert.speech.filters.GammaWindow` when ``frame_style`` is
-        ``'causal'``, otherwise :class:`pydrobert.speech.filters.HannWindow`.
-    use_power : bool, optional
-        Whether the pointwise linearity is the signal's power or
-        magnitude
-    use_log : bool, optional
+        :obj:`'causal'`, otherwise :class:`pydrobert.speech.filters.HannWindow`.
+    use_power
+        Whether the pointwise linearity is the signal's power or magnitude
+    use_log
         Whether to take the log of the integration
-
-    Attributes
-    ----------
-    frame_style : {'causal', 'centered'}
-    sampling_rate : float
-    frame_length : int
-    frame_length_ms : float
-    frame_shift : int
-    frame_shift_ms : float
-    num_coeffs : int
-    started : bool
-    includes_energy : bool
     """
 
-    aliases = {"si"}
+    aliases = {"si"}  #:
 
     def __init__(
         self,
         bank: Union[LinearFilterBank, Mapping, str],
         frame_shift_ms: float = 10,
-        frame_style: Optional[str] = None,
+        frame_style: Optional[Literal["causal", "centered"]] = None,
         include_energy: bool = False,
         pad_to_nearest_power_of_two: bool = True,
-        window_function: Union[WindowFunction, Mapping, str] = None,
+        window_function: Optional[Union[WindowFunction, Mapping, str]] = None,
         use_power: bool = False,
         use_log: bool = True,
     ):
@@ -1048,18 +1009,18 @@ def frame_by_frame_calculation(
 
     Parameters
     ----------
-    computer : FrameComputer
-    signal : array-like
+    computer
+    signal
         A 1D float array of the entire signal
-    chunk_size : int
+    chunk_size
         The length of the signal buffer to process at a given time
 
     Returns
     -------
-    array-like
-        A 2D float array of shape ``(num_frames, num_coeffs)``.
-        ``num_frames`` is nonnegative (possibly 0). Contains some number
-        of feature vectors, ordered in time over axis 0.
+    spec : np.ndarray
+        A 2D float array of shape ``(num_frames, num_coeffs)``. ``num_frames`` is
+        nonnegative (possibly 0). Contains some number of feature vectors, ordered in
+        time over axis 0.
 
     Raises
     ------
