@@ -20,25 +20,25 @@ from typing import Mapping, Optional, Tuple, Union
 
 import numpy as np
 
-from pydrobert.speech import AliasedFactory
-from pydrobert.speech import config
+import pydrobert.speech.config as config
+
+from pydrobert.speech.alias import AliasedFactory, alias_factory_subclass_from_arg
 from pydrobert.speech.scales import MelScaling
 from pydrobert.speech.scales import ScalingFunction
-from pydrobert.speech.util import alias_factory_subclass_from_arg
 from pydrobert.speech.util import angular_to_hertz
 from pydrobert.speech.util import hertz_to_angular
 
 __all__ = [
-    "LinearFilterBank",
-    "TriangularOverlappingFilterBank",
-    "GaborFilterBank",
-    "ComplexGammatoneFilterBank",
-    "WindowFunction",
     "BartlettWindow",
     "BlackmanWindow",
+    "ComplexGammatoneFilterBank",
+    "GaborFilterBank",
+    "GammaWindow",
     "HammingWindow",
     "HannWindow",
-    "GammaWindow",
+    "LinearFilterBank",
+    "TriangularOverlappingFilterBank",
+    "WindowFunction",
 ]
 
 # banks
@@ -50,33 +50,25 @@ class LinearFilterBank(AliasedFactory):
     A :class:`LinearFilterBank` instance is expected to provide factory methods for
     instantiating a fixed number of LTI filters in either the time or frequency domain.
     Filters should be organized lowest frequency first.
-
-    Attributes
-    ----------
-    is_real : bool
-    is_analytic : bool
-    is_zero_phase : bool
-    num_filts : int
-    sampling_rate : float
-    centers_hz : tuple
-    supports_hz : tuple
-    supports : tuple
-    supports_ms : tuple
     """
 
     @abc.abstractproperty
     def is_real(self) -> bool:
-        """Whether the filters are real or complex"""
+        """bool : Whether the filters are real or complex"""
         pass
 
     @abc.abstractproperty
     def is_analytic(self) -> bool:
-        """Whether the filters are (approximately) analytic"""
+        """bool : Whether the filters are (approximately) analytic
+        
+        An analytic signal has no negative frequency components. A real signal cannot
+        be analytic.
+        """
         pass
 
     @abc.abstractproperty
     def is_zero_phase(self) -> bool:
-        """Whether the filters are zero phase or not
+        """bool : Whether the filters are zero phase or not
 
         Zero phase filters are even functions with no imaginary part in the fourier
         domain. Their impulse responses center around 0.
@@ -85,17 +77,17 @@ class LinearFilterBank(AliasedFactory):
 
     @abc.abstractproperty
     def num_filts(self) -> int:
-        """Number of filters in the bank"""
+        """int : Number of filters in the bank"""
         pass
 
     @abc.abstractproperty
     def sampling_rate(self) -> float:
-        """Number of samples in a second of a target recording"""
+        """float : Number of samples in a second of a target recording"""
         pass
 
     @abc.abstractproperty
-    def supports_hz(self) -> Tuple:
-        """Boundaries of effective support of filter freq responses, in Hz.
+    def supports_hz(self) -> Tuple[Tuple[float, float], ...]:
+        """tuple : Boundaries of effective support of filter freq responses, in Hz.
 
         Returns a tuple of length `num_filts` containing pairs of floats of the low and
         high frequencies. Frequencies outside the span have a response of approximately
@@ -116,8 +108,8 @@ class LinearFilterBank(AliasedFactory):
         pass
 
     @abc.abstractproperty
-    def supports(self) -> Tuple:
-        """Boundaries of effective support of filter impulse resps, in samples
+    def supports(self) -> Tuple[Tuple[float, float], ...]:
+        """tuple : Boundaries of effective support of filter impulse resps, in samples
 
         Returns a tuple of length `num_filts` containing pairs of integers of the first
         and last (effectively) nonzero samples.
@@ -135,8 +127,8 @@ class LinearFilterBank(AliasedFactory):
         pass
 
     @property
-    def supports_ms(self) -> tuple:
-        """Boundaries of effective support of filter impulse resps, in ms"""
+    def supports_ms(self) -> Tuple[Tuple[float, float], ...]:
+        """tuple : Boundaries of effective support of filter impulse resps, in ms"""
         return tuple(
             (s[0] * 1000 / self.sampling_rate, s[1] * 1000 / self.sampling_rate,)
             for s in self.supports
@@ -150,15 +142,15 @@ class LinearFilterBank(AliasedFactory):
 
         Parameters
         ----------
-        filt_idx : int
+        filt_idx
             The index of the filter to generate. Less than `num_filts`
-        width : int
+        width
             The length of the buffer, in samples. If less than the support of the
             filter, the filter will alias.
 
         Returns
         -------
-        array-like
+        ir : np.ndarray
             1D float64 or complex128 numpy array of length `width`
         """
         pass
@@ -170,25 +162,24 @@ class LinearFilterBank(AliasedFactory):
         """Construct filter frequency response in a fixed-width buffer
 
         Construct the 2pi-periodized filter in the frequency domain. Zero-phase filters
-        `is_zero_phase` are returned as 8-byte float arrays. Otherwise, they will be
-        16-byte complex floats.
+        are returned as 8-byte float arrays. Otherwise, they will be 16-byte complex
+        floats.
 
         Parameters
         ----------
-        filt_idx : int
+        filt_idx
             The index of the filter to generate. Less than `num_filts`
-        width : int
+        width
             The length of the DFT to output
-        half : bool, optional
-            Whether to return only the DFT bins between [0,pi]
+        half
+            Whether to return only the DFT bins between ``[0,pi]``
 
-        Results
+        Returns
         -------
-        array-like
-            If `half` is `False`, returns a 1D float64 or complex128
-            numpy array of length `width`. If `half` is `True` and
-            `width` is even, the returned array is of length
-            ``width // 2 + 1``. If `width` is odd, the returned array
+        fr : np.ndarray
+            If `half` is :obj:`False`, returns a 1D float64 or complex128 numpy array of
+            length `width`. If `half` is :obj:`True` and `width` is even, the returned
+            array is of length ``width // 2 + 1``. If `width` is odd, the returned array
             is of length ``(width + 1) // 2``.
         """
         pass
@@ -232,14 +223,14 @@ class LinearFilterBank(AliasedFactory):
 
         Parameters
         ----------
-        filt_idx : int
+        filt_idx
             The index of the filter to generate. Less than `num_filts`
-        width : int
+        width
             The length of the DFT to output
 
         Returns
         -------
-        tuple of int, array
+        tfr: tuple of int, array
         """
         pass
 
@@ -253,42 +244,33 @@ class TriangularOverlappingFilterBank(LinearFilterBank):
 
     Parameters
     ----------
-    scaling_function : pydrobert.speech.ScalingFunction, str, or dict
+    scaling_function
         Dictates the layout of filters in the Fourier domain. Can be a
         :class:`ScalingFunction` or something compatible with
-        :func:`pydrobert.speech.alias_factory_subclass_from_arg`
-    num_filts : int, optional
+        :func:`pydrobert.speech.alias.alias_factory_subclass_from_arg`
+    num_filts
         The number of filters in the bank
-    high_hz, low_hz : float, optional
-        The topmost and bottommost edge of the filters, respectively. The default for
-        `high_hz` is the Nyquist
-    sampling_rate : float, optional
+    high_hz
+        The topmost edge of the filter frequencies. The default is the Nyquist for
+        `sampling_rate`.
+    low_hz
+        The bottommost edge of the filter frequences.
+    sampling_rate
         The sampling rate (cycles/sec) of the target recordings
-    analytic : bool, optional
+    analytic
         Whether to use an analytic form of the bank. The analytic form is easily derived
         from the real form in [povey2011]_ and [young]_. Since the filter is compactly
         supported in frequency, the analytic form is simply the suppression of the
         ``[-pi, 0)`` frequencies
 
-    Attributes
-    ----------
-    centers_hz : tuple
-    is_real : bool
-    is_analytic : bool
-    num_filts : int
-    sampling_rate : float
-    supports_hz : tuple
-    supports : tuple
-    supports_ms : tuple
-
     Raises
     ------
     ValueError
-        If `high_hz` is above the Nyquist, or `low_hz` is below 0, or
+        If `high_hz` is above the Nyquist, or `low_hz` is below :obj:`0`, or
         ``high_hz <= low_hz``
     """
 
-    aliases = {"tri", "triangular"}
+    aliases = {"tri", "triangular"}  #:
 
     def __init__(
         self,
@@ -342,22 +324,22 @@ class TriangularOverlappingFilterBank(LinearFilterBank):
         return self._rate
 
     @property
-    def centers_hz(self) -> Tuple[float]:
+    def centers_hz(self) -> Tuple[float, ...]:
         """The point of maximum gain in each filter's frequency response, in Hz
 
-        This property gives the so-called "center frequencies" - the
-        point of maximum gain - of each filter.
+        This property gives the so-called "center frequencies" - the point of maximum
+        gain - of each filter.
         """
         return self._vertices[1:-1]
 
     @property
-    def supports_hz(self) -> tuple:
+    def supports_hz(self) -> Tuple[Tuple[float, float], ...]:
         return tuple(
             (low, high) for low, high in zip(self._vertices[:-2], self._vertices[2:])
         )
 
     @property
-    def supports(self) -> tuple:
+    def supports(self) -> Tuple[Tuple[float, float], ...]:
         # A given filter is bound from above by
         # 2(w_r - w_l) / ((w_c - w_l)(w_r - w_c)t^2pi)
         supports = []
@@ -458,48 +440,38 @@ class TriangularOverlappingFilterBank(LinearFilterBank):
 class Fbank(LinearFilterBank):
     """A mel-triangular filter bank that is square-rooted
 
-    An ``Fbank`` instance is intended to replicate the filters from Kaldi
-    [povey2011]_ and HTK [young]_. Its scale is fixed to Mel-scale. Like a
-    ``TriangularOverlappingFilterBank``, ``Fbank`` places the vertices of
-    triangular filters uniformly along the target scale. However, an ``Fbank``
-    is triangular in the Mel-scale, whereas the triangular bank is triangular
-    in frequency.
+    An ``Fbank`` instance is intended to replicate the filters from Kaldi [povey2011]_
+    and HTK [young]_. Its scale is fixed to Mel-scale. Like a
+    ``TriangularOverlappingFilterBank``, ``Fbank`` places the vertices of triangular
+    filters uniformly along the target scale. However, an ``Fbank`` is triangular in the
+    Mel-scale, whereas the triangular bank is triangular in frequency.
 
     Parameters
     ----------
-    num_filts : int, optional
+    num_filts
         The number of filters in the bank
-    high_hz, low_hz : float, optional
-        The topmost and bottommost edge of the filters, respectively.
-        The default for high_hz is the Nyquist
-    sampling_rate : float, optional
+    high_hz
+        The topmost edge of the filter frequencies. The default is the Nyquist for
+        `sampling_rate`.
+    low_hz
+        The bottommost edge of the filter frequences.
+    sampling_rate 
         The sampling rate (cycles/sec) of the target recordings
-    analytic : bool, optional
-        Whether to use an analytic form of the bank. The analytic form
-        is easily derived from the real form in [1]_ and [2]_. Since
-        the filter is compactly supported in frequency, the analytic
-        form is simply the suppression of the ``[-pi, 0)`` frequencies
-
-    Attributes
-    ----------
-    centers_hz : tuple
-    is_real : bool
-    is_analytic : bool
-    num_filts : int
-    sampling_rate : float
-    supports_hz : tuple
-    supports : tuple
-    supports_ms : tuple
+    analytic
+        Whether to use an analytic form of the bank. The analytic form is easily derived
+        from the real form in [povey2011]_ and [young]_. Since the filter is compactly
+        supported in frequency, the analytic form is simply the suppression of the
+        ``[-pi, 0)`` frequencies
 
     Notes
     -----
-    In a standard mel-filterbank spectrogram, the power spectrum is calculated
-    before filtering. This module's spectrogram takes the power spectrum after
-    filtering. To recreate the frequency response of the alternate order, we
-    can take the pointwise square root of the frequency response.
+    In a standard mel-filterbank spectrogram, the power spectrum is calculated before
+    filtering. This module's spectrogram takes the power spectrum after filtering. To
+    recreate the frequency response of the alternate order, we can take the pointwise
+    square root of the frequency response.
     """
 
-    aliases = {"fbank"}
+    aliases = {"fbank"}  #:
 
     def __init__(
         self,
@@ -550,22 +522,22 @@ class Fbank(LinearFilterBank):
         return self._rate
 
     @property
-    def centers_hz(self) -> Tuple[float]:
-        """The point of maximum gain in each filter's frequency response, in Hz
+    def centers_hz(self) -> Tuple[float, ...]:
+        """tuple : The point of maximum gain in each filter's frequency response, in Hz
 
-        This property gives the so-called "center frequencies" - the
-        point of maximum gain - of each filter.
+        This property gives the so-called "center frequencies" - the point of maximum
+        gain - of each filter.
         """
         return self._vertices[1:-1]
 
     @property
-    def supports_hz(self) -> tuple:
+    def supports_hz(self) -> Tuple[Tuple[float, float], ...]:
         return tuple(
             (low, high) for low, high in zip(self._vertices[:-2], self._vertices[2:])
         )
 
     @property
-    def supports(self) -> tuple:
+    def supports(self) -> Tuple[Tuple[float, float], ...]:
         # A given filter is bound above for t > 0 by
         # ((w_r - w_c) ** .5 + (w_c - w_l) ** .5) /
         #   (2 ** 3 * t ** 3 * (w_c - w_l) * (w_r - w_c) * pi) ** .5
@@ -626,7 +598,9 @@ class Fbank(LinearFilterBank):
                 res[-idx] = val ** 0.5
         return res
 
-    def get_truncated_response(self, filt_idx: int, width: int) -> np.ndarray:
+    def get_truncated_response(
+        self, filt_idx: int, width: int
+    ) -> Tuple[int, np.ndarray]:
         scaling_function = MelScaling()
         left_hz = self._vertices[filt_idx]
         mid_hz = self._vertices[filt_idx + 1]
@@ -681,42 +655,31 @@ class GaborFilterBank(LinearFilterBank):
 
     Parameters
     ----------
-    scaling_function : pydrobert.speech.ScalingFunction, str, or dict
+    scaling_function
         Dictates the layout of filters in the Fourier domain. Can be a
         :class:`ScalingFunction` or something compatible with
-        :func:`pydrobert.speech.alias_factory_subclass_from_arg`
-    num_filts : int
+        :func:`pydrobert.speech.alias.alias_factory_subclass_from_arg`
+    num_filts
         The number of filters in the bank
-    high_hz, low_hz : float, optional
-        The topmost and bottommost edge of the filters, respectively. The default for
-        `high_hz` is the Nyquist
-    sampling_rate : float, optional
+    high_hz
+        The topmost edge of the filter frequencies. The default is the Nyquist for
+        `sampling_rate`.
+    low_hz
+        The bottommost edge of the filter frequences.
+    sampling_rate
         The sampling rate (cycles/sec) of the target recordings
-    scale_l2_norm : bool
+    scale_l2_norm
         Whether to scale the l2 norm of each filter to 1. Otherwise the frequency
         response of each filter will max out at an absolute value of 1.
     erb : bool
 
-    Attributes
-    ----------
-    centers_hz : tuple
-    is_real : bool
-    is_analytic : bool
-    num_filts : int
-    sampling_rate : float
-    supports_hz : tuple
-    supports : tuple
-    supports_ms : tuple
-    scaled_l2_norm : bool
-    erb : bool
-
     See Also
     --------
     pydrobert.speech.config.EFFECTIVE_SUPPORT_THRESHOLD
         The absolute value below which counts as zero
     """
 
-    aliases = {"gabor"}
+    aliases = {"gabor"}  #:
 
     def __init__(
         self,
@@ -830,8 +793,8 @@ class GaborFilterBank(LinearFilterBank):
         return self._rate
 
     @property
-    def centers_hz(self) -> Tuple[float]:
-        """The point of maximum gain in each filter's frequency response, in Hz
+    def centers_hz(self) -> Tuple[float, ...]:
+        """tuple :The point of maximum gain in each filter's frequency response, in Hz
 
         This property gives the so-called "center frequencies" - the
         point of maximum gain - of each filter.
@@ -839,11 +802,11 @@ class GaborFilterBank(LinearFilterBank):
         return self._centers_hz
 
     @property
-    def supports_hz(self) -> tuple:
+    def supports_hz(self) -> Tuple[Tuple[float, float], ...]:
         return self._supports_hz
 
     @property
-    def supports(self) -> tuple:
+    def supports(self) -> Tuple[Tuple[float, float], ...]:
         return self._supports
 
     @property
@@ -901,7 +864,9 @@ class GaborFilterBank(LinearFilterBank):
                 res[idx] += val
         return res
 
-    def get_truncated_response(self, filt_idx: int, width: int) -> np.ndarray:
+    def get_truncated_response(
+        self, filt_idx: int, width: int
+    ) -> Tuple[int, np.ndarray]:
         # wrap_supports_ang contains the angular supports of each filter
         # if the effective support threshold were halved. If this
         # support exceeds the 2pi period, overlap from aliasing in the
@@ -948,7 +913,7 @@ class ComplexGammatoneFilterBank(LinearFilterBank):
 
     .. math::
 
-        H(\omega) = \frac{c(n - 1)!)}{\left(
+        H(\omega) = \frac{c(n - 1)!}{\left(
             \alpha + i(\omega - \xi) \right)^n}
 
     For large :math:`\xi`, the complex gammatone is approximately analytic.
@@ -963,41 +928,29 @@ class ComplexGammatoneFilterBank(LinearFilterBank):
 
     Parameters
     ----------
-    scaling_function : pydrobert.speech.ScalingFunction, str, or dict
+    scaling_function
         Dictates the layout of filters in the Fourier domain. Can be a
         :class:`ScalingFunction` or something compatible with
-        :func:`pydrobert.speech.alias_factory_subclass_from_arg`
-    num_filts : int, optional
+        :func:`pydrobert.speech.alias.alias_factory_subclass_from_arg`
+    num_filts
         The number of filters in the bank
-    high_hz, low_hz : float, optional
-        The topmost and bottommost edge of the filters, respectively. The default for
-        high_hz is the Nyquist
+    high_hz
+        The topmost edge of the filter frequencies. The default is the Nyquist for
+        `sampling_rate`.
+    low_hz
+        The bottommost edge of the filter frequences.
     sampling_rate : float, optional
         The sampling rate (cycles/sec) of the target recordings
-    order : int, optional
+    order
         The :math:`n` parameter in the Gammatone. Should be positive. Larger orders
         will make the gammatone more symmetrical.
-    max_centered : bool, optional
+    max_centered
         While normally causal, setting `max_centered` to true will shift all filters in
         the bank such that the maximum absolute value in time is centered at sample 0.
-    scale_l2_norm : bool
+    scale_l2_norm
         Whether to scale the l2 norm of each filter to 1. Otherwise the frequency
         response of each filter will max out at an absolute value of 1.
-    erb : bool
-
-    Attributes
-    ----------
-    centers_hz : tuple
-    is_real : bool
-    is_analytic : bool
-    num_filts : int
-    order : int
-    sampling_rate : float
-    supports_hz : tuple
-    supports : tuple
-    supports_ms : tuple
-    scaled_l2_norm : bool
-    erb : bool
+    erb
 
     See Also
     --------
@@ -1005,7 +958,7 @@ class ComplexGammatoneFilterBank(LinearFilterBank):
         The absolute value below which counts as zero
     """
 
-    aliases = {"gammatone", "tonebank"}
+    aliases = {"gammatone", "tonebank"}  #:
 
     def __init__(
         self,
@@ -1058,7 +1011,7 @@ class ComplexGammatoneFilterBank(LinearFilterBank):
         log_factorial = np.log(np.math.factorial(order - 1))
         log_2 = np.log(2)
         if erb:
-            alpha_const = (order - 1) * log_2
+            alpha_const = log_2 * (2 * order - 1)
             alpha_const += 2 * log_factorial
             alpha_const -= log_double_factorial
         else:
@@ -1133,20 +1086,20 @@ class ComplexGammatoneFilterBank(LinearFilterBank):
         return self._rate
 
     @property
-    def centers_hz(self) -> Tuple[float]:
-        """The point of maximum gain in each filter's frequency response, in Hz
+    def centers_hz(self) -> Tuple[float, ...]:
+        """int : The point of maximum gain in each filter's frequency response, in Hz
 
-        This property gives the so-called "center frequencies" - the
-        point of maximum gain - of each filter.
+        This property gives the so-called "center frequencies" - the point of maximum
+        gain - of each filter.
         """
         return self._centers_hz
 
     @property
-    def supports_hz(self) -> tuple:
+    def supports_hz(self) -> Tuple[Tuple[float, float], ...]:
         return self._supports_hz
 
     @property
-    def supports(self) -> tuple:
+    def supports(self) -> Tuple[Tuple[float, float], ...]:
         return self._supports
 
     @property
@@ -1182,13 +1135,14 @@ class ComplexGammatoneFilterBank(LinearFilterBank):
         else:
             dft_size = width
         res = np.zeros(dft_size, dtype=np.complex128)
+        omega = np.arange(dft_size, dtype=np.float64) * 2 * np.pi / width
         for period in range(left_period, right_period + 1):
-            for idx in range(dft_size):
-                omega = (idx / width + period) * 2 * np.pi
-                res[idx] += self._H(omega, filt_idx)
+            res += self._H(omega + 2 * np.pi * period, filt_idx)
         return res
 
-    def get_truncated_response(self, filt_idx: int, width: int) -> np.ndarray:
+    def get_truncated_response(
+        self, filt_idx: int, width: int
+    ) -> Tuple[int, np.ndarray]:
         left_sup, right_sup = self._supports_ang[filt_idx]
         wrap_ang = self._wrap_supports_ang[filt_idx]
         # wrap_ang is the additional support needed to hit
@@ -1197,8 +1151,8 @@ class ComplexGammatoneFilterBank(LinearFilterBank):
         # the threshold due to wrapping.
         if right_sup - left_sup + wrap_ang >= 2 * np.pi:
             return 0, self.get_frequency_response(filt_idx, width)
-        left_idx = int(np.ceil(width * left_sup / 2 / np.pi))
-        right_idx = int(width * right_sup / 2 / np.pi)
+        left_idx = int(np.ceil(width * left_sup / (2 * np.pi)))
+        right_idx = int(width * right_sup / (2 * np.pi))
         omega = np.arange(left_idx, right_idx + 1, dtype=np.float64)
         omega *= 2 * np.pi / width
         return left_idx % width, self._H(omega, filt_idx)
@@ -1262,7 +1216,18 @@ class WindowFunction(AliasedFactory):
 
     @abc.abstractmethod
     def get_impulse_response(self, width: int) -> np.ndarray:
-        """Write the filter into a numpy array of fixed width"""
+        """Write the filter into a numpy array of fixed width
+        
+        Parameters
+        ----------
+        width
+            The length of the window in samples
+        
+        Returns
+        -------
+        ir : np.ndarray
+            A 1D vector of length `width`
+        """
         pass
 
 
@@ -1274,7 +1239,7 @@ class BartlettWindow(WindowFunction):
     numpy.bartlett
     """
 
-    aliases = {"bartlett", "triangular", "tri"}
+    aliases = {"bartlett", "triangular", "tri"}  #:
 
     def get_impulse_response(self, width: int) -> np.ndarray:
         window = np.bartlett(width)
@@ -1290,7 +1255,7 @@ class BlackmanWindow(WindowFunction):
     numpy.blackman
     """
 
-    aliases = {"blackman", "black"}
+    aliases = {"blackman", "black"}  #:
 
     def get_impulse_response(self, width: int) -> np.ndarray:
         window = np.blackman(width)
@@ -1306,7 +1271,7 @@ class HammingWindow(WindowFunction):
     numpy.hamming
     """
 
-    aliases = {"hamming"}
+    aliases = {"hamming"}  #:
 
     def get_impulse_response(self, width: int) -> np.ndarray:
         window = np.hamming(width)
@@ -1322,7 +1287,7 @@ class HannWindow(WindowFunction):
     numpy.hanning
     """
 
-    aliases = {"hanning", "hann"}
+    aliases = {"hanning", "hann"}  #:
 
     def get_impulse_response(self, width: int) -> np.ndarray:
         window = np.hanning(width)
@@ -1337,31 +1302,25 @@ class GammaWindow(WindowFunction):
 
     .. math:: p(t; \alpha, n) = t^{n - 1} e^{-\alpha t} u(t)
 
-    Where :math:`n` is the order of the function, :math:`\alpha`
-    controls the bandwidth of the filter, and :math:`u` is the step
-    function.
+    Where :math:`n` is the order of the function, :math:`\alpha` controls the bandwidth
+    of the filter, and :math:`u` is the step function.
 
-    This function returns a window based off a reflected Gamma function.
-    :math:`\alpha` is chosen such that the maximum value of the window
-    aligns with `peak`. The window is clipped to the width. For
-    reasonable values of `peak` (i.e. in the last quarter of samples),
-    the majority of the support should lie in this interval anyways.
+    This function returns a window based off a reflected Gamma function. :math:`\alpha`
+    is chosen such that the maximum value of the window aligns with `peak`. The window
+    is clipped to the width. For reasonable values of `peak` (i.e. in the last quarter
+    of samples), the majority of the support should lie in this interval anyways.
 
     Arguments
     ---------
-    order : int
-    peak : float
-        ``peak * width``, where ``width`` is the length of the window
-        in samples, is where the approximate maximal value of the window
-        lies
-
-    Attributes
-    ----------
-    order : int
-    peak : float
+    order
+    peak
+        ``peak * width``, where ``width`` is the length of the window in samples, is
+        where the approximate maximal value of the window lies
     """
 
-    aliases = {"gamma"}
+    order: int  #:
+    peak: float  #:
+    aliases = {"gamma"}  #:
 
     def __init__(self, order: int = 4, peak: float = 0.75):
         self.order = order
