@@ -23,14 +23,15 @@ from itertools import count
 
 import numpy as np
 
-from pydrobert.speech import AliasedFactory
+from pydrobert.speech.alias import AliasedFactory
 from pydrobert.speech.util import read_signal
 
 __all__ = [
-    "PostProcessor",
-    "Standardize",
     "CMVN",
     "Deltas",
+    "PostProcessor",
+    "Stack",
+    "Standardize",
 ]
 
 
@@ -43,21 +44,20 @@ class PostProcessor(AliasedFactory):
     ) -> np.ndarray:
         """Applies the transformation to a feature tensor
 
-        Consult the class documentation for more details on what the
-        transformation is.
+        Consult the class documentation for more details on what the transformation is.
 
         Parameters
         ----------
-        features : array-like
-        axis : int, optional
+        features
+        axis
             The axis of `features` to apply the transformation along
-        in_place : bool, optional
-            Whether it is okay to modify features (:obj:`True`) or whether
-            a copy should be made (:obj:`False`)
+        in_place
+            Whether it is okay to modify features (:obj:`True`) or whether a copy should
+            be made (:obj:`False`)
 
         Returns
         -------
-        array-like
+        out : np.ndarray
             The transformed features
         """
         pass
@@ -80,12 +80,9 @@ class Standardize(PostProcessor):
 
     Parameters
     ----------
-    rfilename : str, optional
-    norm_var : bool, optional
-
-    Attributes
-    ----------
-    have_stats : bool
+    rfilename
+    norm_var
+    **kwargs
 
     Notes
     -----
@@ -98,9 +95,11 @@ class Standardize(PostProcessor):
         Describes the strategy used for loading signals
     """
 
-    aliases = {"standardize", "normalize", "unit", "cmvn"}
+    aliases = {"standardize", "normalize", "unit", "cmvn"}  #:
 
-    def __init__(self, rfilename: str = None, norm_var: bool = True, **kwargs):
+    def __init__(
+        self, rfilename: Optional[str] = None, norm_var: bool = True, **kwargs
+    ):
         self._stats = None
         self._norm_var = bool(norm_var)
         if rfilename is not None:
@@ -155,7 +154,7 @@ class Standardize(PostProcessor):
 
     @property
     def have_stats(self) -> bool:
-        """Whether at least one feature vector has been accumulated"""
+        """bool : Whether at least one feature vector has been accumulated"""
         return self._stats is not None and self._stats[0, -1]
 
     def _accumulate_vector(self, vec):
@@ -196,19 +195,18 @@ class Standardize(PostProcessor):
 
         Parameters
         ----------
-        features : array-like
-        axis : int, optional
+        features
+        axis
 
         Raises
         ------
-        IndexError
         ValueError
             If the length of `axis` does not match that of past feature
             vector lengths
         """
         if (features.shape and not np.prod(features.shape)) or not len(features):
             raise ValueError("Cannot accumulate from empty array")
-        if features.shape and len(features.shape) > 1:
+        if features.shape and features.ndim > 1:
             self._accumulate_tensor(features, axis)
         else:
             self._accumulate_vector(features)
@@ -301,7 +299,7 @@ class Standardize(PostProcessor):
     ) -> np.ndarray:
         if (features.shape and not np.prod(features.shape)) or not len(features):
             raise ValueError("Cannot apply to empty array")
-        if features.shape and len(features.shape) > 1:
+        if features.shape and features.ndim > 1:
             return self._apply_tensor(features, axis, in_place)
         else:
             return self._apply_vector(features, in_place)
@@ -315,23 +313,24 @@ class Standardize(PostProcessor):
     ) -> None:
         r"""Save accumulated statistics to file
 
-        If `wfilename` ends in `.npy`, stats will be written using :func:`numpy.save`.
+        If `wfilename` ends in :obj:`'.npy'`, stats will be written using
+        :func:`numpy.save`.
 
-        If `wfilename` ends in `.npz`, stats will be written to a numpy archive. If
-        `overwrite` is `False`, other key-values will be loaded first if possible, then
-        resaved. If `key` is set, data will be indexed by `key` in the archive.
-        Otherwise, the data will be stored at the first unused key of the pattern
-        ``'arr_\d+'``. If `compress` is :obj:`True`, :func:`numpy.savez_compressed` will
-        be used over :func:`numpy.savez`.
+        If `wfilename` ends in :obj:`'.npz'`, stats will be written to a numpy archive.
+        If `overwrite` is :obj:`False`, other key-values will be loaded first if
+        possible, then resaved. If `key` is set, data will be indexed by `key` in the
+        archive. Otherwise, the data will be stored at the first unused key of the
+        pattern :obj:`'arr_\d+'`. If `compress` is :obj:`True`,
+        :func:`numpy.savez_compressed` will be used over :func:`numpy.savez`.
 
         Otherwise, data will be written using :func:`numpy.ndarray.tofile`
 
         Parameters
         ----------
-        wfilename : str
-        key : str, optional
-        compress : bool
-        overwrite : bool
+        wfilename
+        key
+        compress
+        overwrite
 
         Raises
         ------
@@ -407,9 +406,9 @@ class Deltas(PostProcessor):
 
     where
 
-    .. math:: Z = \sqrt{\frac{2W^3}{3}}
+    .. math:: Z = \sum_t f(t)^2
 
-    For some :math:`W`. Its Fourier Transform is
+    for some :math:`W \geq 1`. Its Fourier Transform is
 
     .. math::
 
@@ -424,22 +423,20 @@ class Deltas(PostProcessor):
 
     Parameters
     ----------
-    num_deltas : int
-    target_axis : int, optional
-    concatenate : bool
-    context_window : int, optional
-        The length of the filter to either side of the window. Positive
-    pad_mode : str or function, optional
-        How to pad the input sequence when correlating. Additional
-        keyword arguments will be passed to ``numpy.pad()``
-
-    Attributes
-    ----------
-    num_deltas : int
-    concatenate : bool
+    num_deltas
+    target_axis
+    concatenate
+    context_window
+        The length of the filter to either side of the window. Positive.
+    pad_mode
+        How to pad the input sequence when correlating
+    **kwargs
+        Additional keyword arguments to be passed to :func:`numpy.pad`
     """
 
-    aliases = {"deltas"}
+    aliases = {"deltas"}  #:
+    concatenate: bool  #:
+    num_deltas: int  #:
 
     def __init__(
         self,
@@ -448,7 +445,7 @@ class Deltas(PostProcessor):
         concatenate: bool = True,
         context_window: int = 2,
         pad_mode: Union[str, Callable] = "edge",
-        **kwargs
+        **kwargs,
     ):
         self._target_axis = target_axis
         self._pad_mode = pad_mode
@@ -467,12 +464,10 @@ class Deltas(PostProcessor):
     ) -> np.ndarray:
         delta_feats = [features]
         other_axes = tuple(
-            idx
-            for idx in range(len(features.shape))
-            if idx != axis % len(features.shape)
+            idx for idx in range(features.ndim) if idx != axis % features.ndim
         )
         other_shapes = tuple(features.shape[idx] for idx in other_axes)
-        feat_slice = [slice(None)] * len(features.shape)
+        feat_slice = [slice(None)] * features.ndim
         for filt in self._filts[1:]:
             delta_feat = np.empty(features.shape, dtype=features.dtype)
             max_offset = (len(filt) - 1) // 2
@@ -484,7 +479,7 @@ class Deltas(PostProcessor):
                         features[tuple(feat_slice)].astype(np.float64, copy=False),
                         (max_offset, max_offset),
                         self._pad_mode,
-                        **self._pad_kwargs
+                        **self._pad_kwargs,
                     ),
                     filt,
                     "full",
@@ -494,3 +489,75 @@ class Deltas(PostProcessor):
             return np.concatenate(delta_feats, self._target_axis)
         else:
             return np.stack(delta_feats, self._target_axis)
+
+
+class Stack(PostProcessor):
+    """Stack contiguous feature vectors together
+
+    Parameters
+    ----------
+    num_vectors
+        The number of subsequent feature vectors in time to be stacked.
+    time_axis
+        The axis along which subsequent feature vectors are drawn.
+    pad_mode
+        Specified how the axis in time will be padded on the right in order to be
+        divisible by `num_vectors`. Additional keyword arguments will be passed to
+        :func:`numpy.pad`. If unspecified, frames will instead be discarded in order to
+        be divisible by `num_vectors`.
+    """
+
+    aliases = {"stack"}  #:
+    num_vectors: int  #:
+    time_axis: int  #:
+
+    def __init__(
+        self,
+        num_vectors: int,
+        time_axis: int = 0,
+        pad_mode: Optional[Union[str, Callable]] = None,
+        **kwargs,
+    ) -> None:
+        if num_vectors < 1:
+            raise ValueError(f"Expected num_vectors to be positive, got {num_vectors}")
+        self.num_vectors = num_vectors
+        self.time_axis = time_axis
+        self._pad_mode = pad_mode
+        self._pad_kwargs = kwargs
+
+    def apply(
+        self, features: np.ndarray, axis: int = -1, in_place: bool = False
+    ) -> np.ndarray:
+        axis = axis % features.ndim
+        time_axis = self.time_axis % features.ndim
+        if axis == time_axis:
+            raise RuntimeError(f"feature and time axes are the same ({axis})")
+        shape = list(features.shape)
+        T, F = shape[time_axis], shape[axis]
+        if self._pad_mode is not None:
+            rem = T % self.num_vectors
+            if rem:
+                padding = [(0, 0)] * features.ndim
+                padding[time_axis] = (0, self.num_vectors - rem)
+                features = np.pad(features, padding, self._pad_mode, **self._pad_kwargs)
+                in_place = True
+                T += self.num_vectors - rem
+        nT, nF = T // self.num_vectors, F * self.num_vectors
+        T = nT * self.num_vectors
+        if features.ndim == 2:
+            if not in_place:
+                features = features.copy()
+            if time_axis:
+                features = features.T
+            features = features[:T]
+            features = features.reshape(nT, nF)
+            if time_axis:
+                features = features.T
+        else:
+            feat_slice = [slice(None)] * features.ndim
+            buffs = []
+            for i in range(self.num_vectors):
+                feat_slice[time_axis] = slice(i, T, self.num_vectors)
+                buffs.append(features[tuple(feat_slice)])
+            features = np.concatenate(buffs, axis)
+        return features
