@@ -1,7 +1,3 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import warnings
 
@@ -11,12 +7,13 @@ from shutil import rmtree
 import pytest
 
 try:
-    from pydrobert.kaldi import KaldiLocaleWarning
+    from pydrobert.kaldi import KaldiLocaleWarning  # type: ignore
+
     warnings.filterwarnings("ignore", category=KaldiLocaleWarning)
 except ImportError:
     pass
 
-warnings.simplefilter('error')
+warnings.simplefilter("error")
 # # annoying scipy errors. Not mah fault!
 warnings.filterwarnings("ignore", message="numpy.dtype size changed")
 warnings.filterwarnings("ignore", message="numpy.ufunc size changed")
@@ -27,7 +24,7 @@ warnings.filterwarnings("ignore", category=DeprecationWarning)
 # fixtures
 @pytest.fixture
 def temp_file_1_name():
-    temp = NamedTemporaryFile(suffix='_1', delete=False)
+    temp = NamedTemporaryFile(suffix="_1", delete=False)
     temp.close()
     yield temp.name
     os.remove(temp.name)
@@ -35,7 +32,7 @@ def temp_file_1_name():
 
 @pytest.fixture
 def temp_file_2_name():
-    temp = NamedTemporaryFile(suffix='_2', delete=False)
+    temp = NamedTemporaryFile(suffix="_2", delete=False)
     temp.close()
     yield temp.name
     os.remove(temp.name)
